@@ -14,7 +14,7 @@
 
 #include <QPointer>
 
-#include <KgTheme>
+#include <KGameTheme>
 #include <QIcon>
 #include <KGameRenderer>
 #include <KConfigSkeleton>
@@ -85,7 +85,7 @@ void ArenaSelector::showEvent(QShowEvent*)
 
 ArenaSelector::Private::Private(ArenaSelector* parent, Options options) : q(parent), m_options(options), m_arena(nullptr), m_graphicsScene(nullptr), m_svgScaleFactor(1)
 {
-    auto* theme = new KgTheme(QByteArray());
+    auto* theme = new KGameTheme(QByteArray());
     theme->setGraphicsPath(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("themes/granatier.svgz")));
     m_renderer = new KGameRenderer(theme);
 }
@@ -269,7 +269,9 @@ void ArenaSelector::Private::_k_updatePreview(QListWidgetItem* currentItem)
         if (!arenaXmlFile.open(QIODevice::ReadOnly)) {
             qWarning() << " impossible to open file " << arenaXmlFile.fileName();
         }
-        mapParser.parse(&arenaXmlFile);
+        if (!mapParser.parse(&arenaXmlFile)) {
+            qWarning() << " failed to parse file " << arenaXmlFile.fileName();
+        }
         while(!m_arenaItems.isEmpty())
         {
             if(m_graphicsScene->items().contains(m_arenaItems.last()))
