@@ -81,8 +81,9 @@ void PlayerSelector::Private::fillList()
     PlayerSelectorItem* playerSelectorItem;
 
     QSvgRenderer renderer;
-    const qreal dpr = qApp->devicePixelRatio();
-    const int pixmapSize = 64 * dpr;
+    QPixmap pixmap(QSize(64, 64));
+    pixmap.fill(QColor(0, 0, 0, 0));
+    QPainter pixPainter(&pixmap);
 
     QStringList playerIDs = m_playerSettings->playerIDs();
 
@@ -95,17 +96,13 @@ void PlayerSelector::Private::fillList()
         playerSelectorItem = new PlayerSelectorItem(playerIDs[i], m_playerSettings, m_list);
 
         renderer.load(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("players/%1").arg(m_playerSettings->playerGraphicsFile(playerIDs[i]))));
-        QPixmap pixmap(QSize(pixmapSize, pixmapSize));
-        pixmap.fill(QColor(0, 0, 0, 0));
-        QPainter pixPainter(&pixmap);
         renderer.render(&pixPainter, QStringLiteral("player_0"));
-        pixmap.setDevicePixelRatio(dpr);
         playerSelectorItem->setPlayerPreviewPixmap(pixmap);
 
         KConfig desktopFile(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("players/%1").arg(playerIDs[i])), KConfig::SimpleConfig);
-        auto author = desktopFile.group("KGameTheme").readEntry<QString>("Author", QStringLiteral(""));
-        QString authorEmail = QStringLiteral("<a href=\"mailto:%1\">%1</a>").arg(desktopFile.group("KGameTheme").readEntry<QString>("AuthorEmail", QStringLiteral("")));
-        //TODO: QString description = desktopFile.group("KGameTheme").readEntry<QString>("Description", "");
+        auto author = desktopFile.group(QStringLiteral("KGameTheme")).readEntry<QString>("Author", QStringLiteral(""));
+        QString authorEmail = QStringLiteral("<a href=\"mailto:%1\">%1</a>").arg(desktopFile.group(QStringLiteral("KGameTheme")).readEntry<QString>("AuthorEmail", QStringLiteral("")));
+        //TODO: QString description = desktopFile.group(QStringLiteral("KGameTheme")).readEntry<QString>("Description", "");
         playerSelectorItem->setPlayerAuthor(author, authorEmail);
 
         modelIndex = m_list->model()->index(i, 0, m_list->rootIndex());
